module.exports = defineTest({
	description: 'consistent renaming test'
});
